/// <reference types="node" />
import 'source-map-support/register.js';
import type { SnowpackDevServer, ServerRuntime as SnowpackServerRuntime, SnowpackConfig } from 'snowpack';
import type { CompileError } from 'astro-parser';
import type { LogOptions } from './logger';
import type { AstroConfig, CollectionRSS, RuntimeMode } from './@types/astro';
interface RuntimeConfig {
    astroConfig: AstroConfig;
    logging: LogOptions;
    mode: RuntimeMode;
    backendSnowpack: SnowpackDevServer;
    backendSnowpackRuntime: SnowpackServerRuntime;
    backendSnowpackConfig: SnowpackConfig;
    frontendSnowpack: SnowpackDevServer;
    frontendSnowpackRuntime: SnowpackServerRuntime;
    frontendSnowpackConfig: SnowpackConfig;
}
interface CollectionInfo {
    additionalURLs: Set<string>;
    rss?: {
        data: any[] & CollectionRSS;
    };
}
declare type LoadResultSuccess = {
    statusCode: 200;
    contents: string | Buffer;
    contentType?: string | false;
};
declare type LoadResultNotFound = {
    statusCode: 404;
    error: Error;
    collectionInfo?: CollectionInfo;
};
declare type LoadResultRedirect = {
    statusCode: 301 | 302;
    location: string;
    collectionInfo?: CollectionInfo;
};
declare type LoadResultError = {
    statusCode: 500;
} & ({
    type: 'parse-error';
    error: CompileError;
} | {
    type: 'unknown';
    error: Error;
});
export declare type LoadResult = (LoadResultSuccess | LoadResultNotFound | LoadResultRedirect | LoadResultError) & {
    collectionInfo?: CollectionInfo;
};
export interface AstroRuntime {
    runtimeConfig: RuntimeConfig;
    load: (rawPathname: string | undefined) => Promise<LoadResult>;
    shutdown: () => Promise<void>;
}
interface RuntimeOptions {
    mode: RuntimeMode;
    logging: LogOptions;
}
/** Core Astro runtime */
export declare function createRuntime(astroConfig: AstroConfig, { mode, logging }: RuntimeOptions): Promise<AstroRuntime>;
export {};
